<?php

namespace Superrobota\Log\Policies;

use Litepie\User\Contracts\UserPolicy;
use Superrobota\Log\Models\Log;

class LogPolicy
{

    /**
     * Determine if the given user can view the log.
     *
     * @param UserPolicy $user
     * @param Log $log
     *
     * @return bool
     */
    public function view(UserPolicy $user, Log $log)
    {
        if ($user->canDo('log.log.view') && $user->isAdmin()) {
            return true;
        }

        return $log->user_id == user_id() && $log->user_type == user_type();
    }

    /**
     * Determine if the given user can create a log.
     *
     * @param UserPolicy $user
     * @param Log $log
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('log.log.create');
    }

    /**
     * Determine if the given user can update the given log.
     *
     * @param UserPolicy $user
     * @param Log $log
     *
     * @return bool
     */
    public function update(UserPolicy $user, Log $log)
    {
        if ($user->canDo('log.log.edit') && $user->isAdmin()) {
            return true;
        }

        return $log->user_id == user_id() && $log->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given log.
     *
     * @param UserPolicy $user
     * @param Log $log
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Log $log)
    {
        return $log->user_id == user_id() && $log->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given log.
     *
     * @param UserPolicy $user
     * @param Log $log
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Log $log)
    {
        if ($user->canDo('log.log.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given log.
     *
     * @param UserPolicy $user
     * @param Log $log
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Log $log)
    {
        if ($user->canDo('log.log.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
